@@ -17,7 +17,7 @@ from django.views import generic
 
 from horizon.browsers.views import AngularIndexView
 
-import api
+from heat_dashboard.content.template_generator import api
 
 
 class IndexView(AngularIndexView):
@@ -25,12 +25,6 @@ class IndexView(AngularIndexView):
     page_title = _("Template Generator")
 
 
-class ApiView(generic.View):
-    def get(self, request):
-        return HttpResponse(api.get_resources(request),
-                            content_type="application/json")
-
-
 class OptionView(generic.View):
     def get(self, request):
         return HttpResponse(api.get_resource_options(request),
